
// ClipsPlayer.java
// Andrew Davison, April 2009, ad@fivedots.coe.psu.ac.th

/* ClipsPlayer  stores a collection of AudioClip objects
   in a HashMap whose keys are their filenames (minus .wav). 
   The clip files are assumed to be in Sounds/.

   When a clip is played, the play() method doesn't return until
   a specified delay time has passed.
*/


import java.util.*;
import java.applet.*;



public class ClipsPlayer
{
  private final static String SOUND_DIR = "Sounds/";    // directory holding the clips

  private HashMap<String,AudioClip> clipsMap; 
        // string is the filename (minus .wav) holding the clip



  public ClipsPlayer()
  {  clipsMap = new HashMap<String,AudioClip>();  } 




  public boolean play(String name, int delay)
  // start playing the clip, and wait for delay ms before returning
  {  
    if (!clipsMap.containsKey(name))
      addClip(name);

    AudioClip clip = clipsMap.get(name);
    if (clip == null) {
      System.out.println("No clip found for " + name);
      return false;
    }
    clip.play();
    wait(delay);
    return true;
  }  // end of play()



  private boolean addClip(String name)
  // store the AudioClip object for name in the hashmap
  {
    AudioClip clip = loadClip(name);
    if (clip != null) {
      clipsMap.put(name, clip);
      System.out.println("Loaded clip for " + name);
      return true;
    }
    return false;
  }  // end of addClip()



  private AudioClip loadClip(String name)
  // load name.wav from SOUND_DIR
  {
    String fnm = SOUND_DIR + name + ".wav";

    AudioClip clip = null;
    try {
	  clip = Applet.newAudioClip( getClass().getResource(fnm) );
    }
    catch (Exception e) {
      System.out.println("Could not load " + fnm);
    }
    return clip;
  }  // end of loadClip()



  private void wait(int delay)
  {
    try {
      Thread.sleep(delay); // in ms
    } 
    catch (InterruptedException e) 
    { e.printStackTrace(); }
  }  // end of wait()


/*
  // -------------------- test rig ----------------------

  public static void main(String[] args)
  {  
     if (args.length != 1)
       System.out.println("Usage: java ClipsPlayer <filename in Sounds/>");
     else {
       ClipsPlayer cp = new ClipsPlayer(); 
       cp.play(args[0], 2000);    // delay an arbirary amount of time
     }
  }
*/
}  // end of ClipsPlayer class
