
// MethodWord.java
// Andrew Davison, April 2009, ad@fivedots.coe.psu.ac.th

/*  Store the word that will be spoken for a given
    class and method name pair.
*/

import java.io.*;
import java.util.*;


public class MethodWord
{
  private static final int MIN_LEN = 4;

  private String className, methodName;
  private String wordToSay;


  public MethodWord(String cName, String mName, MethodWords mWords)
  {  
    className = cName;
    methodName = mName;
   
    wordToSay = buildWord(methodName, mWords);
    System.out.println(className + ":" + methodName + 
                            "() is represented by the word \"" + wordToSay + "\"");
  }  // end of MethodWord()



  private String buildWord(String mName, MethodWords mWords)
  {
    if (mName.length() < MIN_LEN)   // if method name is short, use it as the word to say
      if (mWords.isUnique(mName))
        return mName;

    // shorten method name
    String shortName;
    for (int i= MIN_LEN; i <= mName.length(); i++) {
      shortName = mName.substring(0, i);
      if (mWords.isUnique(shortName))
        return shortName;
    }

    // if we get to here then no substring of mName is unique
    // so add class name to it's front, and try again

    String longName = className + " " + mName;
    for (int i= (className.length()+1)+MIN_LEN; i <= longName.length(); i++) {
      shortName = longName.substring(0, i);
      if (mWords.isUnique(shortName))
        return shortName;
    }

    // if we get to here then no substring of "className mName" is unique
    // so keep adding a number to mName, until it's unique
    int count = 1;
    String numName = mName + " " + count;
    while (!mWords.isUnique(numName)) {
      count++;
      numName = mName + " " + count;
    }
    return numName;
  }  // end of buildWord()



  public boolean equals(String cName, String mName)
  {  return className.equals(cName) && methodName.equals(mName);  } 


  public String getWord()
  {  return wordToSay; } 

}  // end of MethodWord class
