
// MethodWords.java
// Andrew Davison, April 2009, ad@fivedots.coe.psu.ac.th

/*  Store all the MethodWords objects used in the application.
*/

import java.io.*;
import java.util.*;

import com.sun.jdi.*;



public class MethodWords
{
  private ArrayList<MethodWord> mWords;   
            // stores the words that will be spoken when methods are called


  public MethodWords()
  {  mWords = new ArrayList<MethodWord>();  } 



  public void addMethods(String className, List<Method> methods)
  // add all the methods which are not already in the MethodWords list
  { for(Method meth : methods)
      addMethod(className, meth);
  }  // end of addMethods()



  public void addMethod(String className, Method meth)
  // add MethodWord object for the method in the class, if not already there
  {
    if (getWord(className, meth) != null)  // already present
      return;  // don't add

    MethodWord mw;
    if (meth.isConstructor())
      mw = new MethodWord(className, className, this);   // use class name for the constructor
    else
      mw = new MethodWord(className, meth.name(), this);
    mWords.add(mw);
  }  // end of addMethod()



  public String getWord(String className, Method meth)
  // find the word that should be said for className.methodName()
  {
    for (MethodWord mw : mWords) {
      if (meth.isConstructor()) {
        if (mw.equals(className, className))   // use class name for the constructor
          return mw.getWord();
      }
      else if (mw.equals(className, meth.name()))
        return mw.getWord();
    }

    return null;  // nothing found that matches
  }  // end of getWord()



  public boolean isUnique(String word)
  // is word unique in the MethodWords list?
  // called by MethodWord
  {
    for (MethodWord mw : mWords)
      if (word.equals( mw.getWord() ))
        return false;
    return true;
  }  // end of isUnique()

}  // end of MethodWords class
