
// ListVoices.java
// Andrew Davison, ad@fivedots.coe.psu.ac.th, April 2009

/* List all the synthesizers and voices known to FreeTTS

   If you use Central class then place speech.properties in
   JAVA_HOME (C:\Program Files\Java\jdk1.6.0_10) \jre\lib
 */


import java.io.File;
import java.util.*;


import com.sun.speech.freetts.jsapi.FreeTTSEngineCentral;
import javax.speech.*;
import javax.speech.synthesis.*;


public class ListVoices
{

  public static void main(String args[]) 
  { 
    System.out.println("All available JSAPI Synthesizers and Voices:");
    
    EngineList engineList = getEngines();

    // loop over the synthesizers
    for (int e = 0; e < engineList.size(); e++) {            
      SynthesizerModeDesc desc = (SynthesizerModeDesc) engineList.get(e);
      // loop over all the voices for this synthesizer
      Voice[] voices = desc.getVoices();
      for (Voice voice : voices)
        System.out.println( "  " + desc.getEngineName() +
                    ": Voice: " + voice.getName() + 
                    "; Gender: " + genderStr( voice.getGender() ));
    }  
    System.out.println();
  } // end of main()



  private static EngineList getEngines()
  {
    // Don't set any properties so all the synthesizers will be returned
    SynthesizerModeDesc emptyDesc = new SynthesizerModeDesc();     

    EngineList engineList = null;
    try {
      // engineList = Central.availableSynthesizers( emptyDesc );
      FreeTTSEngineCentral central = new FreeTTSEngineCentral();   // so no need for "speech.properties"
      engineList = central.createEngineList(emptyDesc);
    } 
    catch (Exception e) 
    {  System.out.println(e); 
       System.exit(1);
    }

    return engineList;
  }  // end of getEngines()


  private static String genderStr(int gender) 
  {
    switch (gender) {       
      case Voice.GENDER_FEMALE: return "female";
      case Voice.GENDER_MALE: return "male";
      case Voice.GENDER_NEUTRAL: return "neutral";
      case Voice.GENDER_DONT_CARE:
      default: return "unknown";
    }        
  }  // end of genderStr()
  

} // end of ListVoices class
